@@ -5,8 +5,8 @@
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; Package-Requires: ((emacs "28.1"))
 ;; URL: https://github.com/xenodium/time-zones
-;; Package-Version: 20251103.936
-;; Package-Revision: 23c866db6a3a
+;; Package-Version: 20260205.2126
+;; Package-Revision: 5513f14d857a
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -139,7 +139,7 @@ Each item is an alist containing keys like:
 (defvar time-zones--cursor-original-type nil
   "Original cursor type before hiding.")
 
-(defconst time-zones--version "0.5.1"
+(defconst time-zones--version "0.5.2"
   "Version of the `time-zones' package.")
 
 (defun time-zones--cursor-hide ()
@@ -324,6 +324,16 @@ Uses `completing-read' for selection."
 
 (defconst time-zones--fallback-flag "🏴")
 
+;; Based on https://lars.ingebrigtsen.no/2025/01/11/wordpress-statistics-me
+(defun time-zones--country-flag-from-iso2 (code)
+  "Generate flag emoji from 2-letter ISO CODE.
+Converts each letter to a Regional Indicator Symbol by adding #x1f1a5."
+  (when-let* ((code code)
+              ((= (length code) 2))
+              (code (upcase code)))
+    (string (+ #x1f1a5 (elt code 0))
+            (+ #x1f1a5 (elt code 1)))))
+
 (defun time-zones--fetch-posix-tz-mappings ()
   "Download and parse the IANA to POSIX TZ mappings JSON data.
 Returns an alist of (IANA-TZ . POSIX-TZ) pairs."
@@ -387,7 +397,8 @@ Returns an alist of (IANA-TZ . POSIX-TZ) pairs."
       (seq-doseq (state (map-elt country 'states))
         (seq-doseq (city (map-elt state 'cities))
           (puthash (format "%s %s - %s, %s"
-                           (or (time-zones--country-flag (map-elt country 'name))
+                           (or (map-elt country 'emoji)
+                               (time-zones--country-flag-from-iso2 (map-elt country 'iso2))
                                time-zones--fallback-flag)
                            (map-elt country 'name)
                            (map-elt city 'name)
@@ -397,7 +408,9 @@ Returns an alist of (IANA-TZ . POSIX-TZ) pairs."
                      (city . ,(map-elt city 'name))
                      (timezone . ,(time-zones--resolve-timezone (map-elt city 'timezone)))
                      (latitude . ,(map-elt city 'latitude))
-                     (longitude . ,(map-elt city 'longitude)))
+                     (longitude . ,(map-elt city 'longitude))
+                     (flag . ,(or (map-elt country 'emoji)
+                                  (time-zones--country-flag-from-iso2 (map-elt country 'iso2)))))
                    timezones))))
     timezones))
 
@@ -646,40 +659,47 @@ and MAX-OFFSET-WIDTH."
              (propertize "?" 'face 'help-key-binding)
              " help")))
     (insert title)
-    (when time-zones--city-list
-      (let* ((sorted-cities (funcall time-zones-sorting-function
-                                     time-zones--city-list local-time))
-             (max-location-width
-              (apply #'max
-                     (mapcar (lambda (city)
-                               (let* ((city-name (map-elt city 'city))
-                                      (state (map-elt city 'state))
-                                      (timezone (map-elt city 'timezone))
-                                      (location (or city-name state timezone)))
-                                 (length location)))
-                             sorted-cities)))
-             (max-date-width
-              (apply #'max
-                     (mapcar (lambda (city)
-                               (length (format-time-string "%A %d %B" local-time (map-elt city 'timezone))))
-                             sorted-cities)))
-             (max-abbreviation-width
-              (apply #'max
-                     (mapcar (lambda (city)
-                               (length (time-zones--format-tz-abbreviation local-time (map-elt city 'timezone))))
-                             sorted-cities)))
-             (max-offset-width
-              (if time-zones-show-details
-                  (apply #'max
-                         (mapcar (lambda (city)
-                                   (length (time-zones--format-utc-or-home-offset local-time (map-elt city 'timezone))))
-                                 sorted-cities))
-                0)))
-        (dolist (city sorted-cities)
-          (insert (time-zones--format-city city local-time max-location-width
-                                           max-date-width max-abbreviation-width max-offset-width)))))
-    (unless (seq-empty-p time-zones--city-list)
-      (insert "\n"))
+    (if time-zones--city-list
+        (let* ((sorted-cities (funcall time-zones-sorting-function
+                                       time-zones--city-list local-time))
+               (max-location-width
+                (apply #'max
+                       (mapcar (lambda (city)
+                                 (let* ((city-name (map-elt city 'city))
+                                        (state (map-elt city 'state))
+                                        (timezone (map-elt city 'timezone))
+                                        (location (or city-name state timezone)))
+                                   (length location)))
+                               sorted-cities)))
+               (max-date-width
+                (apply #'max
+                       (mapcar (lambda (city)
+                                 (length (format-time-string "%A %d %B" local-time (map-elt city 'timezone))))
+                               sorted-cities)))
+               (max-abbreviation-width
+                (apply #'max
+                       (mapcar (lambda (city)
+                                 (length (time-zones--format-tz-abbreviation local-time (map-elt city 'timezone))))
+                               sorted-cities)))
+               (max-offset-width
+                (if time-zones-show-details
+                    (apply #'max
+                           (mapcar (lambda (city)
+                                     (length (time-zones--format-utc-or-home-offset local-time (map-elt city 'timezone))))
+                                   sorted-cities))
+                  0)))
+          (dolist (city sorted-cities)
+            (insert (time-zones--format-city city local-time max-location-width
+                                             max-date-width max-abbreviation-width max-offset-width)))
+          (insert "\n"))
+      ;; Display message when no time zones are configured
+      (insert "  Press "
+              (propertize (key-description
+                           (where-is-internal 'time-zones-add-city
+                                              time-zones-mode-map t))
+                          'face 'help-key-binding)
+              " to add a city time zone"
+              "\n\n"))
     (if time-zones-show-help
         (progn
           (insert "  "
@@ -715,171 +735,6 @@ returns IANA-TZ as-is."
             iana-tz))  ; Fallback to IANA if no mapping found
     iana-tz))
 
-(defun time-zones--country-flag (country-name)
-  "Get the flag emoji for COUNTRY-NAME."
-  (map-elt '(("Afghanistan" . "🇦🇫")
-             ("Albania" . "🇦🇱")
-             ("Algeria" . "🇩🇿")
-             ("Andorra" . "🇦🇩")
-             ("Angola" . "🇦🇴")
-             ("Argentina" . "🇦🇷")
-             ("Armenia" . "🇦🇲")
-             ("Australia" . "🇦🇺")
-             ("Austria" . "🇦🇹")
-             ("Azerbaijan" . "🇦🇿")
-             ("Bahrain" . "🇧🇭")
-             ("Bangladesh" . "🇧🇩")
-             ("Belarus" . "🇧🇾")
-             ("Belgium" . "🇧🇪")
-             ("Belize" . "🇧🇿")
-             ("Benin" . "🇧🇯")
-             ("Bhutan" . "🇧🇹")
-             ("Bolivia" . "🇧🇴")
-             ("Bosnia and Herzegovina" . "🇧🇦")
-             ("Botswana" . "🇧🇼")
-             ("Brazil" . "🇧🇷")
-             ("Brunei" . "🇧🇳")
-             ("Bulgaria" . "🇧🇬")
-             ("Burkina Faso" . "🇧🇫")
-             ("Burundi" . "🇧🇮")
-             ("Cambodia" . "🇰🇭")
-             ("Cameroon" . "🇨🇲")
-             ("Canada" . "🇨🇦")
-             ("Central African Republic" . "🇨🇫")
-             ("Chad" . "🇹🇩")
-             ("Chile" . "🇨🇱")
-             ("China" . "🇨🇳")
-             ("Colombia" . "🇨🇴")
-             ("Comoros" . "🇰🇲")
-             ("Costa Rica" . "🇨🇷")
-             ("Croatia" . "🇭🇷")
-             ("Cuba" . "🇨🇺")
-             ("Cyprus" . "🇨🇾")
-             ("Czech Republic" . "🇨🇿")
-             ("Denmark" . "🇩🇰")
-             ("Djibouti" . "🇩🇯")
-             ("Dominican Republic" . "🇩🇴")
-             ("Ecuador" . "🇪🇨")
-             ("Egypt" . "🇪🇬")
-             ("El Salvador" . "🇸🇻")
-             ("Estonia" . "🇪🇪")
-             ("Eswatini" . "🇸🇿")
-             ("Ethiopia" . "🇪🇹")
-             ("Finland" . "🇫🇮")
-             ("France" . "🇫🇷")
-             ("Gabon" . "🇬🇦")
-             ("Georgia" . "🇬🇪")
-             ("Germany" . "🇩🇪")
-             ("Ghana" . "🇬🇭")
-             ("Greece" . "🇬🇷")
-             ("Guatemala" . "🇬🇹")
-             ("Guinea" . "🇬🇳")
-             ("Guinea-Bissau" . "🇬🇼")
-             ("Guyana" . "🇬🇾")
-             ("Haiti" . "🇭🇹")
-             ("Honduras" . "🇭🇳")
-             ("Hungary" . "🇭🇺")
-             ("Iceland" . "🇮🇸")
-             ("India" . "🇮🇳")
-             ("Indonesia" . "🇮🇩")
-             ("Iran" . "🇮🇷")
-             ("Iraq" . "🇮🇶")
-             ("Ireland" . "🇮🇪")
-             ("Israel" . "🇮🇱")
-             ("Italy" . "🇮🇹")
-             ("Jamaica" . "🇯🇲")
-             ("Japan" . "🇯🇵")
-             ("Jordan" . "🇯🇴")
-             ("Kazakhstan" . "🇰🇿")
-             ("Kenya" . "🇰🇪")
-             ("Kuwait" . "🇰🇼")
-             ("Kyrgyzstan" . "🇰🇬")
-             ("Laos" . "🇱🇦")
-             ("Latvia" . "🇱🇻")
-             ("Lebanon" . "🇱🇧")
-             ("Lesotho" . "🇱🇸")
-             ("Liberia" . "🇱🇷")
-             ("Libya" . "🇱🇾")
-             ("Liechtenstein" . "🇱🇮")
-             ("Lithuania" . "🇱🇹")
-             ("Luxembourg" . "🇱🇺")
-             ("Madagascar" . "🇲🇬")
-             ("Malawi" . "🇲🇼")
-             ("Malaysia" . "🇲🇾")
-             ("Maldives" . "🇲🇻")
-             ("Mali" . "🇲🇱")
-             ("Malta" . "🇲🇹")
-             ("Mauritania" . "🇲🇷")
-             ("Mauritius" . "🇲🇺")
-             ("Mexico" . "🇲🇽")
-             ("Moldova" . "🇲🇩")
-             ("Monaco" . "🇲🇨")
-             ("Mongolia" . "🇲🇳")
-             ("Montenegro" . "🇲🇪")
-             ("Morocco" . "🇲🇦")
-             ("Mozambique" . "🇲🇿")
-             ("Myanmar" . "🇲🇲")
-             ("Namibia" . "🇳🇦")
-             ("Nepal" . "🇳🇵")
-             ("Netherlands" . "🇳🇱")
-             ("New Zealand" . "🇳🇿")
-             ("Nicaragua" . "🇳🇮")
-             ("Niger" . "🇳🇪")
-             ("Nigeria" . "🇳🇬")
-             ("North Korea" . "🇰🇵")
-             ("North Macedonia" . "🇲🇰")
-             ("Norway" . "🇳🇴")
-             ("Oman" . "🇴🇲")
-             ("Pakistan" . "🇵🇰")
-             ("Panama" . "🇵🇦")
-             ("Paraguay" . "🇵🇾")
-             ("Peru" . "🇵🇪")
-             ("Philippines" . "🇵🇭")
-             ("Poland" . "🇵🇱")
-             ("Portugal" . "🇵🇹")
-             ("Qatar" . "🇶🇦")
-             ("Romania" . "🇷🇴")
-             ("Russia" . "🇷🇺")
-             ("Rwanda" . "🇷🇼")
-             ("Saudi Arabia" . "🇸🇦")
-             ("Senegal" . "🇸🇳")
-             ("Serbia" . "🇷🇸")
-             ("Singapore" . "🇸🇬")
-             ("Slovakia" . "🇸🇰")
-             ("Slovenia" . "🇸🇮")
-             ("Somalia" . "🇸🇴")
-             ("South Africa" . "🇿🇦")
-             ("South Korea" . "🇰🇷")
-             ("South Sudan" . "🇸🇸")
-             ("Spain" . "🇪🇸")
-             ("Sri Lanka" . "🇱🇰")
-             ("Sudan" . "🇸🇩")
-             ("Suriname" . "🇸🇷")
-             ("Sweden" . "🇸🇪")
-             ("Switzerland" . "🇨🇭")
-             ("Syria" . "🇸🇾")
-             ("Taiwan" . "🇹🇼")
-             ("Tajikistan" . "🇹🇯")
-             ("Tanzania" . "🇹🇿")
-             ("Thailand" . "🇹🇭")
-             ("Togo" . "🇹🇬")
-             ("Tunisia" . "🇹🇳")
-             ("Turkey" . "🇹🇷")
-             ("Turkmenistan" . "🇹🇲")
-             ("Uganda" . "🇺🇬")
-             ("Ukraine" . "🇺🇦")
-             ("United Arab Emirates" . "🇦🇪")
-             ("United Kingdom" . "🇬🇧")
-             ("United States" . "🇺🇸")
-             ("Uruguay" . "🇺🇾")
-             ("Uzbekistan" . "🇺🇿")
-             ("Venezuela" . "🇻🇪")
-             ("Vietnam" . "🇻🇳")
-             ("Yemen" . "🇾🇪")
-             ("Zambia" . "🇿🇲")
-             ("Zimbabwe" . "🇿🇼"))
-           country-name))
-
 (provide 'time-zones)
 
 ;;; time-zones.el ends here
